==> scala-k8s-objects_2.12-0.3.0-sources.jar: io/k8s/api/autoscaling/v2/ResourceMetricSource.scala <==
package io.k8s.api.autoscaling.v2

import dev.hnaderi.k8s.utils._

/** ResourceMetricSource indicates how to scale on a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  The values will be averaged together before being compared to the target.  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.  Only one "target" type should be set. */
final case class ResourceMetricSource(
  name : String,
  target : io.k8s.api.autoscaling.v2.MetricTarget
) {

  /** Returns a new data with name set to new value */
  def withName(value: String) : ResourceMetricSource = copy(name = value)
  /** transforms name to result of function */
  def mapName(f: String => String) : ResourceMetricSource = copy(name = f(name))

  /** Returns a new data with target set to new value */
  def withTarget(value: io.k8s.api.autoscaling.v2.MetricTarget) : ResourceMetricSource = copy(target = value)
  /** transforms target to result of function */
  def mapTarget(f: io.k8s.api.autoscaling.v2.MetricTarget => io.k8s.api.autoscaling.v2.MetricTarget) : ResourceMetricSource = copy(target = f(target))
}

object ResourceMetricSource {

    implicit def encoder[T](implicit builder : Builder[T]) : Encoder[io.k8s.api.autoscaling.v2.ResourceMetricSource, T] = new Encoder[io.k8s.api.autoscaling.v2.ResourceMetricSource, T] {
        def apply(o: io.k8s.api.autoscaling.v2.ResourceMetricSource) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("name", o.name)
            .write("target", o.target)
            .build
        }
    }

    implicit def decoderOf[T : Reader] : Decoder[T, ResourceMetricSource] = new Decoder[T, ResourceMetricSource] {
      def apply(t: T): Either[String, ResourceMetricSource] = for {
          obj <- ObjectReader(t)
          name <- obj.read[String]("name")
          target <- obj.read[io.k8s.api.autoscaling.v2.MetricTarget]("target")
      } yield ResourceMetricSource (
          name = name,
          target = target
        )
    }
}

==> scala-k8s-objects_3-0.5.0-sources.jar: io/k8s/api/autoscaling/v2/ResourceMetricSource.scala <==
package io.k8s.api.autoscaling.v2

import dev.hnaderi.k8s.utils._

/** ResourceMetricSource indicates how to scale on a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  The values will be averaged together before being compared to the target.  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.  Only one "target" type should be set. */
final case class ResourceMetricSource(
  name : String,
  target : io.k8s.api.autoscaling.v2.MetricTarget
) {

  /** Returns a new data with name set to new value */
  def withName(value: String) : ResourceMetricSource = copy(name = value)
  /** transforms name to result of function */
  def mapName(f: String => String) : ResourceMetricSource = copy(name = f(name))

  /** Returns a new data with target set to new value */
  def withTarget(value: io.k8s.api.autoscaling.v2.MetricTarget) : ResourceMetricSource = copy(target = value)
  /** transforms target to result of function */
  def mapTarget(f: io.k8s.api.autoscaling.v2.MetricTarget => io.k8s.api.autoscaling.v2.MetricTarget) : ResourceMetricSource = copy(target = f(target))
}

object ResourceMetricSource {

    implicit val encoder : Encoder[io.k8s.api.autoscaling.v2.ResourceMetricSource] = new Encoder[io.k8s.api.autoscaling.v2.ResourceMetricSource] {
        def apply[T : Builder](o: io.k8s.api.autoscaling.v2.ResourceMetricSource) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("name", o.name)
            .write("target", o.target)
            .build
        }
    }

    implicit val decoder: Decoder[ResourceMetricSource] = new Decoder[ResourceMetricSource] {
      def apply[T : Reader](t: T): Either[String, ResourceMetricSource] = for {
          obj <- ObjectReader(t)
          name <- obj.read[String]("name")
          target <- obj.read[io.k8s.api.autoscaling.v2.MetricTarget]("target")
      } yield ResourceMetricSource (
          name = name,
          target = target
        )
    }
}
